import equal from 'fast-deep-equal';
import Scheduler from './Scheduler';
class SwiperScheduler extends Scheduler {
    constructor(params) {
        var _a;
        super({
            dataCount: ((_a = params.dataSource) === null || _a === void 0 ? void 0 : _a.length) || 0,
            loop: params.loop || false,
            defaultDataIndex: params.defaultMarkIndex,
            minCount: params.minCount || 3,
            onDataIndexChange: (detail) => {
                this.emitMarkIndexChange(detail);
            },
            onRestart: (detail) => {
                this.emitRestart(detail);
            },
            onRecompute: () => this.recompute(),
            onContainerIndexChange: (detail) => {
                this.emitSwiperIndexChange(detail);
            },
        });
        this.markIndexOfDelay = 0;
        this.source = [];
        this.setup(params);
    }
    get circular() {
        if (this.loop)
            return true;
        // 使用 markIndexOfDelay 的原因是：如果使用 markIndex 及时更新，会导致swiper组件props变更，动画消失
        return this.markIndexOfDelay !== 0 && this.markIndexOfDelay !== this.maxDataIndex;
    }
    updateDataSource(value) {
        if (equal(value, this.dataSource))
            return this.dataSource;
        this.dataSource = value;
        this.updateCount(this.dataSource.length);
        // return this.emitRestart({
        //   containerIndex: this.getContainerIndex(),
        //   dataIndex: this.getDataIndex()
        // })
        return this.recompute();
    }
    nextSection() {
        return this.offsetSection(1);
    }
    prevSection() {
        return this.offsetSection(-1);
    }
    setup(params) {
        const { dataSource = [], defaultMarkIndex = 0, loop = false, onSwiperRestart, onSwiperIndexChange, onSwiperSourceChange, onMarkIndexChange, } = params;
        this.dataSource = dataSource;
        this.loop = loop;
        this.setMarkIndex(defaultMarkIndex);
        this.onSwiperRestart = onSwiperRestart;
        this.onSwiperIndexChange = onSwiperIndexChange;
        this.onSwiperSourceChange = onSwiperSourceChange;
        this.onMarkIndexChange = onMarkIndexChange;
        this.recompute();
    }
    /**
     * 判断当前swiperIndex是否是active状态
     * @param index
     */
    getActiveStatusBySwiperIndex(index) {
        const targetMarkIndex = this.indexMapping.get(index);
        return this.markIndexOfDelay === targetMarkIndex;
    }
    async toSection(dataIndex) {
        const step = this.getStepOffset(dataIndex);
        if (Math.abs(step) === 1) {
            return this.offsetSection(step);
        }
        const markIndex = await this.setMarkIndex(this.getSafeDataIndex(dataIndex));
        const swiperIndex = this.setSwiperIndex(this.computeContainerIndex());
        return {
            swiperIndex,
            markIndex
        };
    }
    async offsetSection(step) {
        const markIndex = await this.setMarkIndex(this.getDataIndex() + step);
        const swiperIndex = this.setSwiperIndex(this.computeContainerIndex(step));
        return {
            swiperIndex,
            markIndex
        };
    }
    emitRestart({ containerIndex, dataIndex }) {
        var _a;
        const source = this.recompute();
        (_a = this.onSwiperRestart) === null || _a === void 0 ? void 0 : _a.call(this, {
            swiperIndex: containerIndex,
            markIndex: dataIndex,
            key: Date.now().toString(36).slice(0, 8),
            source
        });
        return source;
    }
    emitSwiperIndexChange({ containerIndex, dataIndex }) {
        var _a;
        (_a = this.onSwiperIndexChange) === null || _a === void 0 ? void 0 : _a.call(this, {
            swiperIndex: containerIndex,
            markIndex: dataIndex,
        });
    }
    emitMarkIndexChange({ dataIndex }) {
        var _a;
        (_a = this.onMarkIndexChange) === null || _a === void 0 ? void 0 : _a.call(this, {
            markIndex: dataIndex
        });
    }
    recompute() {
        const result = super.recomputeIndexArr();
        const source = result.map(index => this.dataSource[index]);
        this.updateMarkIndexOfDelay();
        this.setSource(source);
        return source;
    }
    setMarkIndex(markIndex) {
        return super.updateIndex(markIndex);
    }
    setSwiperIndex(swiperIndex) {
        return super.setContainerIndex(swiperIndex);
    }
    setSource(source) {
        var _a;
        if (equal(this.source, source))
            return;
        this.source = source;
        (_a = this.onSwiperSourceChange) === null || _a === void 0 ? void 0 : _a.call(this, this.source);
        return this.source;
    }
    updateMarkIndexOfDelay() {
        this.markIndexOfDelay = this.getDataIndex();
    }
}
export default SwiperScheduler;
//# sourceMappingURL=SwiperScheduler.js.map